@@ -9,12 +9,12 @@ pylibftdi: http://bitbucket.org/codedstructure/pylibftdi
 
 libftdi can be found at:
  http://www.intra2net.com/en/developer/libftdi/
-Neither libftdi or Intra2net are associated with this project;
+Neither libftdi nor Intra2net are associated with this project;
 if something goes wrong here, it's almost definitely my fault
 rather than a problem with the libftdi library.
 """
 
-__VERSION__ = "0.9"
+__VERSION__ = "0.10"
 __AUTHOR__ = "Ben Bass"
 
 
@@ -39,13 +39,3 @@ BB_INPUT = bitbang.BB_INPUT
 FLUSH_BOTH = driver.FLUSH_BOTH
 FLUSH_INPUT = driver.FLUSH_INPUT
 FLUSH_OUTPUT = driver.FLUSH_OUTPUT
-
-# LEGACY SUPPORT
-
-
-class BitBangDriver(bitbang.BitBangDevice):
-    def __init__(self, direction=ALL_OUTPUTS):
-        import warnings
-        warnings.warn('change BitBangDriver reference to BitBangDevice',
-                      DeprecationWarning)
-        return BitBangDevice.__init__(self, direction=direction, lazy_open=True)
